@@ -32,7 +32,7 @@ Standard library reorganization
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 ``from future import standard_library`` provides a context-manager called
-``enable_hooks`` that installs import hooks (PEP 3108) to allow renamed and
+``hooks`` that installs import hooks (PEP 3108) to allow renamed and
 moved standard library modules to be imported from their new Py3 locations.
 
 
@@ -80,7 +80,7 @@ __license__ = 'MIT'
 __copyright__ = 'Copyright 2014 Python Charmers Pty Ltd'
 __ver_major__ = 0
 __ver_minor__ = 11
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__, __ver_minor__,
                               __ver_patch__, __ver_sub__)
