@@ -2,10 +2,11 @@
 from __future__ import absolute_import, division, print_function
 
 import pprint
+import tempfile
 from subprocess import Popen, PIPE
 import os
 
-from future.tests.base import CodeHandler, unittest
+from future.tests.base import CodeHandler, unittest, skip26
 
 
 class TestFuturizeSimple(CodeHandler):
@@ -14,6 +15,9 @@ class TestFuturizeSimple(CodeHandler):
     tests for whether they can be passed to ``futurize`` and immediately
     run under both Python 2 again and Python 3.
     """
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp() + os.path.sep
+        super(TestFuturizeSimple, self).setUp()
 
     @unittest.expectedFailure
     def test_problematic_string(self):
@@ -71,13 +75,25 @@ class TestFuturizeSimple(CodeHandler):
             pass
         """
         after = """
-        from __future__ import unicode_literals
         from future.builtins import zip
         for (a, b) in zip([1, 3, 5], [2, 4, 6]):
             pass
         """
         self.convert_check(before, after, stages=(1, 2), ignore_imports=False)
 
+    def test_UserList(self):
+        before = """
+        from UserList import UserList
+        a = UserList([1, 3, 5])
+        assert len(a) == 3
+        """
+        after = """
+        from collections import UserList
+        a = UserList([1, 3, 5])
+        assert len(a) == 3
+        """
+        self.convert_check(before, after, stages=(1, 2), ignore_imports=True)
+
     @unittest.expectedFailure
     def test_no_unneeded_list_calls(self):
         """
@@ -89,6 +105,7 @@ class TestFuturizeSimple(CodeHandler):
         """
         self.unchanged(code)
 
+    @unittest.expectedFailure
     def test_import_builtins(self):
         before = """
         a = raw_input()
@@ -99,10 +116,10 @@ class TestFuturizeSimple(CodeHandler):
         f = bytes(a, encoding='utf-8')
         for g in xrange(10**10):
             pass
+        h = reduce(lambda x, y: x+y, [1, 2, 3, 4, 5])
         super(MyClass, self)
         """
         after = """
-        from __future__ import unicode_literals
         from future.builtins import bytes
         from future.builtins import filter
         from future.builtins import input
@@ -110,6 +127,7 @@ class TestFuturizeSimple(CodeHandler):
         from future.builtins import open
         from future.builtins import range
         from future.builtins import super
+        from functools import reduce
         a = input()
         b = open(a, b, c)
         c = list(filter(a, b))
@@ -118,6 +136,7 @@ class TestFuturizeSimple(CodeHandler):
         f = bytes(a, encoding='utf-8')
         for g in range(10**10):
             pass
+        h = reduce(lambda x, y: x+y, [1, 2, 3, 4, 5])
         super(MyClass, self)
         """
         self.convert_check(before, after, ignore_imports=False, run=False)
@@ -129,6 +148,7 @@ class TestFuturizeSimple(CodeHandler):
         '''
         self.convert(code)
     
+    @skip26
     @unittest.expectedFailure
     def test_source_coding_utf8(self):
         """
@@ -220,6 +240,7 @@ class TestFuturizeSimple(CodeHandler):
         # with open('/tmp/' + filename, 'w') as tarball:
         #     tarball.write(r2.content)
 
+    @unittest.expectedFailure
     def test_raw_input(self):
         """
         Passes in a string to the waiting input() after futurize
@@ -229,18 +250,34 @@ class TestFuturizeSimple(CodeHandler):
             http://docs.python.org/2/library/2to3.html
         """
         before = """
+        from io import BytesIO
         def greet(name):
             print "Hello, {0}!".format(name)
         print "What's your name?"
+        import sys
+        oldstdin = sys.stdin
+
+        sys.stdin = BytesIO(b'Ed\\n')
         name = raw_input()
-        greet(name)
+        greet(name.decode())
+
+        sys.stdin = oldstdin
+        assert name == b'Ed'
         """
         desired = """
+        from io import BytesIO
         def greet(name):
             print("Hello, {0}!".format(name))
         print("What's your name?")
+        import sys
+        oldstdin = sys.stdin
+
+        sys.stdin = BytesIO(b'Ed\\n')
         name = input()
-        greet(name)
+        greet(name.decode())
+
+        sys.stdin = oldstdin
+        assert name == b'Ed'
         """
         self.convert_check(before, desired, run=False)
 
@@ -248,6 +285,7 @@ class TestFuturizeSimple(CodeHandler):
             p1 = Popen([interpreter, self.tempdir + 'mytestscript.py'],
                        stdout=PIPE, stdin=PIPE, stderr=PIPE, env=self.env)
             (stdout, stderr) = p1.communicate(b'Ed')
+            self.assertEqual(stderr, b'')
             self.assertEqual(stdout, b"What's your name?\nHello, Ed!\n")
 
     def test_literal_prefixes_are_not_stripped(self):
@@ -287,16 +325,12 @@ class TestFuturizeRenamedStdlib(CodeHandler):
         import copy_reg
         import cPickle
         import cStringIO
-
-        s = cStringIO.StringIO('blah')
         """
         after = """
         import configparser
         import copyreg
         import pickle
         import io
-
-        s = io.StringIO('blah')
         """
         self.convert_check(before, after)
     
@@ -365,21 +399,31 @@ class TestFuturizeRenamedStdlib(CodeHandler):
     @unittest.expectedFailure
     def test_Py2_StringIO_module(self):
         """
+        This requires that the argument to io.StringIO be made a
+        unicode string explicitly if we're not using unicode_literals:
+
         Ideally, there would be a fixer for this. For now:
 
-        TODO: add the Py3 equivalent for this to the docs
+        TODO: add the Py3 equivalent for this to the docs. Also add back
+        a test for the unicode_literals case.
         """
         before = """
         import cStringIO
-        s = cStringIO.StringIO('my string')
-        assert isinstance(s, cStringIO.InputType)
+        import StringIO
+        s1 = cStringIO.StringIO('my string')
+        s2 = StringIO.StringIO('my other string')
+        assert isinstance(s1, cStringIO.InputType)
         """
+
+        # There is no io.InputType in Python 3. futurize should change this to
+        # something like this. But note that the input to io.StringIO
+        # must be a unicode string on both Py2 and Py3.
         after = """
         import io
-        s = io.StringIO('my string')
-        # assert isinstance(s, io.InputType)
-        # There is no io.InputType in Python 3. What should we change this to
-        # instead?
+        import io
+        s1 = io.StringIO(u'my string')
+        s2 = io.StringIO(u'my other string')
+        assert isinstance(s1, io.StringIO)
         """
         self.convert_check(before, after)
 
@@ -435,7 +479,7 @@ class TestFuturizeStage1(CodeHandler):
 
         Issue #16 (with porting bokeh/bbmodel.py)
         """
-        with open('specialmodels.py', 'w') as f:
+        with open(tempdir + 'specialmodels.py', 'w') as f:
             f.write('pass')
 
         before = """
